package yrpg.bamp.basedata.webapi;


import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import kd.bos.bd.service.AssignService;
import kd.bos.dataentity.entity.DynamicObject;
import kd.bos.dataentity.entity.DynamicObjectCollection;
import kd.bos.dataentity.utils.StringUtils;
import kd.bos.entity.basedata.BaseDataResponse;
import kd.bos.openapi.api.result.ApiSaveItemData;
import kd.bos.openapi.api.result.ApiSaveResult;
import kd.bos.openapi.api.result.ApiSaveRowErrorData;
import kd.bos.openapi.api.result.BaseFilterResult;
import kd.bos.openapi.api.result.BaseFilterItemData;
import kd.bos.openapi.common.custom.annotation.ApiController;
import kd.bos.openapi.common.custom.annotation.ApiParam;
import kd.bos.openapi.common.custom.annotation.ApiPostMapping;
import kd.bos.openapi.common.custom.annotation.ApiResponseBody;
import kd.bos.openapi.common.result.CustomApiResult;
import kd.bos.openapi.common.result.OpenApiResult;
import kd.bos.openapi.common.util.OpenApiSdkUtil;
import kd.bos.orm.query.QCP;
import kd.bos.orm.query.QFilter;
import kd.bos.servicehelper.BusinessDataServiceHelper;
import kd.bos.servicehelper.QueryServiceHelper;


import javax.validation.Valid;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;

@ApiController(value="CustomBill",desc="统一url入口")
public class CustomController {


    @ApiPostMapping(value="batchSyncCustom")
    public CustomApiResult<@ApiResponseBody("Body") Map<String,Object>> costCenterApiHandler(@Valid @ApiParam("入口参数") CostCenterApiReqModel reqModel) {
        String reqData=reqModel.getData();
        JSONArray reqList = JSONObject.parseArray(reqData);

        //获取系统现有客户数据,并且将系统中的启用禁用状态、主数据ID分别放入两个map,分组判断时从map中获取数据
        Map<String,String> sysEnableStatusMap = new HashMap<String,String>();
        Map<String,String> entityCodeMap = new HashMap<String,String>();
        Map<String,String> mainIdMap = new HashMap<String,String>();
        Map<String,Set<Long>> customAssignIds = new HashMap<String,Set<Long>>();
        DynamicObjectCollection systemCustomList = QueryServiceHelper.query("bd_customer", "number,enable", new QFilter[]{});
        for(DynamicObject sysCustomData : systemCustomList){
            sysEnableStatusMap.put(sysCustomData.getString("number"),sysCustomData.getString("enable"));
        }


        JSONArray saveList = new JSONArray();       //只需要进行save操作的数据
        JSONArray enableList = new JSONArray();     //启用数据,先进行启用操作，再save
        JSONArray disableList = new JSONArray();    //禁用数据，直接禁用操作，不需要save
        JSONArray doneList = new JSONArray();       //不需要进行任何操作的数据，返回时直接认为操作成功
        JSONArray noNumberList = new JSONArray();       //传入的数据没有number，直接做失败处理
        List<String> disableIds = new ArrayList<String>();
        List<String> enableIds = new ArrayList<String>();

        //数据分组，根据系统中是否已存在、启用、禁用状态进行分组
        for(int i=0; i<reqList.size(); i++){
            JSONObject reqJson = reqList.getJSONObject(i);
            String number = reqJson.getString("number");
            entityCodeMap.put(number,reqJson.getString("entityCode"));
            mainIdMap.put(number,reqJson.getString("yrpg_main_id"));
            String enableStatus = reqJson.getString("enable");

            //根据分配组织code获取分配组织ID
            JSONArray customOrgArray = reqJson.getJSONArray("custom_org");
            List<String> codes = new ArrayList<String>();
            Set<Long> orgIds = new HashSet<Long>();
            if(customOrgArray != null && customOrgArray.size()>0){
                for(int n=0;n<customOrgArray.size();n++){
                    codes.add(customOrgArray.getJSONObject(n).getString("code"));
                }
            }
            QFilter filtersup = new QFilter("yrpg_companynum", QCP.in,codes);//单据状态
            QFilter[] supfilters = new QFilter[]{filtersup};
            DynamicObject[] orgbills= BusinessDataServiceHelper.load("bos_org","id",supfilters);
            for(DynamicObject orgbill:orgbills){
                orgIds.add(Long.parseLong(orgbill.getString("id")));
            }
            customAssignIds.put(number,orgIds);

            //--------------传入number为空的数据-------------
            if(StringUtils.isBlank(number) || StringUtils.isEmpty(number)){
                noNumberList.add(reqJson);
            } else if(sysEnableStatusMap.get(number) == null){
                //-------------------系统中赞不存在的数据------------------------
                if("0".equals(enableStatus)){
                    //不存在，且需要禁用的，不做处理，放入doneList
                    doneList.add(reqJson);
                }else{
                    //不存在，且需要启用的，直接save，默认就是开启状态，放入saveList
                    saveList.add(reqJson);
                }
            }else{
                //-------------------系统中已存在的数据---------------------
                if("1".equals(enableStatus) && "1".equals(sysEnableStatusMap.get(number))){
                    //启用，系统中已经是启用状态的,只需要save,放入saveList
                    saveList.add(reqJson);
                } else if ("1".equals(enableStatus) && "0".equals(sysEnableStatusMap.get(number))) {
                    //启用，系统中是禁用状态的,放入enableList
                    enableList.add(reqJson);
                    enableIds.add(number);
                } else if ("0".equals(enableStatus) && "0".equals(sysEnableStatusMap.get(number))) {
                    //禁用，系统中已经是禁用状态的，不需要任何操作，放入doneList
                    doneList.add(reqJson);
                }else if("0".equals(enableStatus) && "1".equals(sysEnableStatusMap.get(number))){
                    //禁用，系统中是启用状态的额，放入disableList
                    disableList.add(reqJson);
                    disableIds.add(number);
                }else{
                    //不满足条件的统一不做任何处理
                    doneList.add(reqJson);
                }
            }
            //-------------------分组判断结束------------------------------
        }

        List<JSONObject> mdMappingsList = new ArrayList<JSONObject>();


        //save数据处理
        if(saveList.size() > 0){
            JSONObject saveJson = new JSONObject();
            saveJson.put("data",saveList);
            OpenApiResult saveReult = OpenApiSdkUtil.invoke("/v2/yrpg/basedata/bd_customer/saveCostomer", saveJson, new HashMap<>());
            groupListNew(mdMappingsList,saveReult,entityCodeMap,mainIdMap,customAssignIds,"save",saveList);
        }

        //禁用数据处理
        if(disableList.size() > 0){
            JSONObject disableJson = new JSONObject();
            JSONObject ids = new JSONObject();
            ids.put("number",disableIds);
             disableJson.put("data",ids);
            OpenApiResult disableReult = OpenApiSdkUtil.invoke("/v2/yrpg/basedata/bd_customer/bd_customer_disable", disableJson, new HashMap<>());
            groupList(mdMappingsList,disableReult,entityCodeMap,mainIdMap,customAssignIds,"disable");
        }
        //启用数据处理


        if(enableList.size() > 0) {
            JSONObject enableJson = new JSONObject();
            JSONObject ids = new JSONObject();
            ids.put("number",enableIds);
            enableJson.put("data",ids);
            //调用启用接口
            OpenApiSdkUtil.invoke("/v2/yrpg/basedata/bd_customer/bd_customer_enable", enableJson, new HashMap<>());
            //反审核
            OpenApiSdkUtil.invoke("/v2/yrpg/basedata/bd_customer/bd_customer_unaudit", enableJson, new HashMap<>());
            //调用save接口
            enableJson.put("data",enableList);
            OpenApiResult saveReult = OpenApiSdkUtil.invoke("/v2/yrpg/basedata/bd_customer/saveCostomer", enableJson, new HashMap<>());
            groupList(mdMappingsList, saveReult, entityCodeMap,mainIdMap,customAssignIds, "save");
        }

        //不需要操作的数据直接封装成功返回
        if(doneList.size()>0){
            for(int i=0;i<doneList.size();i++){
                JSONObject reqJson = doneList.getJSONObject(i);
                JSONObject json = new JSONObject();
                json.put("mdmCode",reqJson.getString("yrpg_main_id"));
                json.put("entityCode",reqJson.getString("entityCode"));
                json.put("busiDataId","");
                json.put("message","该条主数据消费成功！");
                json.put("success",true);
                mdMappingsList.add(json);
            }
        }

        //没有number的数据返回
        if(noNumberList.size()>0){
            for(int i=0;i<noNumberList.size();i++){
                JSONObject reqJson = noNumberList.getJSONObject(i);
                JSONObject json = new JSONObject();
                json.put("mdmCode",reqJson.getString("yrpg_main_id"));
                json.put("entityCode",reqJson.getString("entityCode"));
                json.put("busiDataId","");
                json.put("message","number不能为空");
                json.put("success",false);
                mdMappingsList.add(json);
            }

        }

        Map<String,Object> result = new HashMap<String,Object>();
        result.put("success",true);
        result.put("message", "消费系统消费这批数据成功！");
        result.put("mdMappings",mdMappingsList);
        return CustomApiResult.success(result);
    }


    @ApiPostMapping(value="batchSyncTerminalCustom")
    public CustomApiResult<@ApiResponseBody("Body") Map<String,Object>> batchSyncTerminalCustom(@Valid @ApiParam("入口参数") CostCenterApiReqModel reqModel) {
        String reqData=reqModel.getData();
        JSONArray reqList = JSONObject.parseArray(reqData);

        //获取系统现有客户数据,并且将系统中的启用禁用状态、主数据ID分别放入两个map,分组判断时从map中获取数据
        Map<String,String> sysEnableStatusMap = new HashMap<String,String>();
        Map<String,String> entityCodeMap = new HashMap<String,String>();
        Map<String,String> mainIdMap = new HashMap<String,String>();
        DynamicObjectCollection systemCustomList = QueryServiceHelper.query("yrpg_bd_endcustomer", "number,enable", new QFilter[]{});
        for(DynamicObject sysCustomData : systemCustomList){
            sysEnableStatusMap.put(sysCustomData.getString("number"),sysCustomData.getString("enable"));
        }


        JSONArray saveList = new JSONArray();       //只需要进行save操作的数据
        JSONArray enableList = new JSONArray();     //启用数据,先进行启用操作，再save
        JSONArray disableList = new JSONArray();    //禁用数据，直接禁用操作，不需要save
        JSONArray doneList = new JSONArray();       //不需要进行任何操作的数据，返回时直接认为操作成功
        List<String> disableIds = new ArrayList<String>();
        List<String> enableIds = new ArrayList<String>();

        //数据分组，根据系统中是否已存在、启用、禁用状态进行分组
        for(int i=0; i<reqList.size(); i++){
            JSONObject reqJson = reqList.getJSONObject(i);
            String number = reqJson.getString("number");
            entityCodeMap.put(number,reqJson.getString("entityCode"));
            mainIdMap.put(number,reqJson.getString("yrpg_main_id"));
            String enableStatus = reqJson.getString("enable");


            //-------------------系统中赞不存在的数据------------------------
            if(sysEnableStatusMap.get(number) == null){
                if("0".equals(enableStatus)){
                    //不存在，且需要禁用的，不做处理，放入doneList
                    doneList.add(reqJson);
                }else{
                    //不存在，且需要启用的，直接save，默认就是开启状态，放入saveList
                    saveList.add(reqJson);
                }
            }else{
                //-------------------系统中已存在的数据---------------------
                if("1".equals(enableStatus) && "1".equals(sysEnableStatusMap.get(number))){
                    //启用，系统中已经是启用状态的,只需要save,放入saveList
                    saveList.add(reqJson);
                } else if ("1".equals(enableStatus) && "0".equals(sysEnableStatusMap.get(number))) {
                    //启用，系统中是禁用状态的,放入enableList
                    enableList.add(reqJson);
                    enableIds.add(number);
                } else if ("0".equals(enableStatus) && "0".equals(sysEnableStatusMap.get(number))) {
                    //禁用，系统中已经是禁用状态的，不需要任何操作，放入doneList
                    doneList.add(reqJson);
                }else if("0".equals(enableStatus) && "1".equals(sysEnableStatusMap.get(number))){
                    //禁用，系统中是启用状态的额，放入disableList
                    disableList.add(reqJson);
                    disableIds.add(number);
                }else{
                    //不满足条件的统一不做任何处理
                    doneList.add(reqJson);
                }
            }
            //-------------------分组判断结束------------------------------
        }

        List<JSONObject> mdMappingsList = new ArrayList<JSONObject>();


        //save数据处理
        if(saveList.size() > 0){
            JSONObject saveJson = new JSONObject();
            saveJson.put("data",saveList);
            OpenApiResult saveReult = OpenApiSdkUtil.invoke("/v2/yrpg/basedata/yrpg_bd_endcustomer/endcustomer_save", saveJson, new HashMap<>());
            groupTerminalList(mdMappingsList,saveReult,entityCodeMap,mainIdMap,"save");
        }

        //禁用数据处理
        if(disableList.size() > 0){
            JSONObject disableJson = new JSONObject();
            JSONObject ids = new JSONObject();
            ids.put("number",disableIds);
            disableJson.put("data",ids);
            OpenApiResult disableReult = OpenApiSdkUtil.invoke("/v2/yrpg/basedata/yrpg_bd_endcustomer/endcustomer_disable", disableJson, new HashMap<>());
            groupTerminalList(mdMappingsList,disableReult,entityCodeMap,mainIdMap,"disable");
        }
        //启用数据处理


        if(enableList.size() > 0) {
            JSONObject enableJson = new JSONObject();
            JSONObject ids = new JSONObject();
            ids.put("number",enableIds);
            enableJson.put("data",ids);
            //调用启用接口
            OpenApiSdkUtil.invoke("/v2/yrpg/basedata/yrpg_bd_endcustomer/endcustomer_enable", enableJson, new HashMap<>());
            //反审核
            OpenApiSdkUtil.invoke("/v2/yrpg/basedata/yrpg_bd_endcustomer/endcustomer_unaudit", enableJson, new HashMap<>());
            //调用save接口
            enableJson.put("data",enableList);
            OpenApiResult saveReult = OpenApiSdkUtil.invoke("/v2/yrpg/basedata/yrpg_bd_endcustomer/endcustomer_save", enableJson, new HashMap<>());
            groupTerminalList(mdMappingsList, saveReult, entityCodeMap,mainIdMap, "save");
        }

        //不需要操作的数据直接封装成功返回
        if(doneList.size()>0){
            for(int i=0;i<doneList.size();i++){
                JSONObject reqJson = doneList.getJSONObject(i);
                JSONObject json = new JSONObject();
                json.put("mdmCode",reqJson.getString("yrpg_main_id"));
                json.put("entityCode",reqJson.getString("entityCode"));
                json.put("busiDataId","");
                json.put("message","该条主数据消费成功！");
                json.put("success",true);
                mdMappingsList.add(json);
            }
        }

        Map<String,Object> result = new HashMap<String,Object>();
        result.put("success",true);
        result.put("message", "消费系统消费这批数据成功！");
        result.put("mdMappings",mdMappingsList);
        return CustomApiResult.success(result);
    }

    private void groupListNew(List<JSONObject> mdMappingsList,OpenApiResult result,Map<String,String>entityCodeMap,Map<String,String>mainIdMap,Map<String,Set<Long>> customAssignIds,String operateType,JSONArray saveList){
        String entity = "bd_customer";
        String tempId = "100000";
        String appId = "basedata";
        Long useOrgId = Long.parseLong(tempId);
        AssignService assignService = new AssignService(entity, false);
        if("save".equals(operateType)) {

            for (int i = 0; i < saveList.size(); i++) {
                JSONObject reqJson = saveList.getJSONObject(i);
                JSONObject jsonNew = new JSONObject();
                jsonNew.put("mdmCode", reqJson.getString("yrpg_main_id"));
                jsonNew.put("entityCode", reqJson.getString("entityCode"));
                jsonNew.put("busiDataId", "");
               // jsonNew.put("message", "该条主数据消费成功！");
                ApiSaveResult data = (ApiSaveResult) result.getData();
                List<ApiSaveItemData> saveItemList = data.getResult();
                for (ApiSaveItemData item : saveItemList) {
                   // JSONObject json = new JSONObject();
                    String mdmCode = item.getKeys().get("number");
                    String yrpgCode = item.getKeys().get("yrpg_code");
                    if (!StringUtils.isEmpty(yrpgCode) && !StringUtils.equals(yrpgCode, reqJson.getString("yrpg_code"))) {
                        continue;
                    }


//                json.put("mdmCode",mainIdMap.get(mdmCode));
//                json.put("entityCode",entityCodeMap.get(mdmCode));
                    jsonNew.put("busiDataId", item.getId());
                    jsonNew.put("success", item.isBillStatus());
                    if (item.isBillStatus()) {
                        //save成功的客户分配组织
                        Set<Long> dataIds = new HashSet<Long>();
                        dataIds.add(Long.parseLong(item.getId()));
                        BaseDataResponse response = assignService.assign(useOrgId, appId, dataIds, customAssignIds.get(mdmCode), false);
                        if (!response.isSuccess()) {
                            jsonNew.put("message", response.getErrorMsg());
                            jsonNew.put("success", false);
                        } else {
                            jsonNew.put("message", "该条主数据消费成功！");
                        }
                    } else {
                        StringBuffer errmsg = new StringBuffer();
                        for (ApiSaveRowErrorData errer : item.getErrors()) {
                            //明细错误拼接
                            Set<String> rowMsg = errer.getRowMsg();
                            for (String err : rowMsg) {
                                errmsg.append(err);
                            }
                        }
                        jsonNew.put("message", errmsg.toString());

                    }
                }
                mdMappingsList.add(jsonNew);
            }
        }else{
            BaseFilterResult data = (BaseFilterResult)result.getData();
            List<BaseFilterItemData> itemList = data.getResult();
            for(BaseFilterItemData item : itemList){
                JSONObject json = new JSONObject();
                String mdmCode = item.getNumber();
                json.put("mdmCode",mainIdMap.get(mdmCode));
                json.put("entityCode",entityCodeMap.get(mdmCode));
                json.put("busiDataId",item.getId());
                json.put("success",item.isBillStatus());
                if(item.isBillStatus()){
                    json.put("message","该条主数据消费成功！");
                }else{
                    StringBuffer errmsg = new StringBuffer();
                    List<String> errors = item.getErrors();
                    for(String err : errors){
                        errmsg.append(err);
                    }
                    json.put("message",errmsg.toString());
                }
                mdMappingsList.add(json);
            }

        }
    }





    private void groupList(List<JSONObject> mdMappingsList,OpenApiResult result,Map<String,String>entityCodeMap,Map<String,String>mainIdMap,Map<String,Set<Long>> customAssignIds,String operateType){
        String entity = "bd_customer";
        String tempId = "100000";
        String appId = "basedata";
        Long useOrgId = Long.parseLong(tempId);
        AssignService assignService = new AssignService(entity, false);
        if("save".equals(operateType)){
            ApiSaveResult data = (ApiSaveResult)result.getData();
            List<ApiSaveItemData> saveItemList = data.getResult();
            for(ApiSaveItemData item : saveItemList){
                JSONObject json = new JSONObject();
                String mdmCode = item.getKeys().get("number");
                json.put("mdmCode",mainIdMap.get(mdmCode));
                json.put("entityCode",entityCodeMap.get(mdmCode));
                json.put("busiDataId",item.getId());
                json.put("success",item.isBillStatus());
                if(item.isBillStatus()){
                    //save成功的客户分配组织
                    Set<Long> dataIds = new HashSet<Long>();
                    dataIds.add(Long.parseLong(item.getId()));
                    BaseDataResponse response = assignService.assign(useOrgId, appId, dataIds, customAssignIds.get(mdmCode), false);
                    if(!response.isSuccess()){
                        json.put("message",response.getErrorMsg());
                        json.put("success",false);
                    }else{
                        json.put("message","该条主数据消费成功！");
                    }
                }else{
                    StringBuffer errmsg = new StringBuffer();
                    for(ApiSaveRowErrorData errer:item.getErrors()){
                        //明细错误拼接
                        Set<String> rowMsg = errer.getRowMsg();
                        for(String err:rowMsg){
                            errmsg.append(err);
                        }
                    }
                    json.put("message",errmsg.toString());

                }
                mdMappingsList.add(json);
            }
        }else{
            BaseFilterResult data = (BaseFilterResult)result.getData();
            List<BaseFilterItemData> itemList = data.getResult();
            for(BaseFilterItemData item : itemList){
                JSONObject json = new JSONObject();
                String mdmCode = item.getNumber();
                json.put("mdmCode",mainIdMap.get(mdmCode));
                json.put("entityCode",entityCodeMap.get(mdmCode));
                json.put("busiDataId",item.getId());
                json.put("success",item.isBillStatus());
                if(item.isBillStatus()){
                    json.put("message","该条主数据消费成功！");
                }else{
                    StringBuffer errmsg = new StringBuffer();
                    List<String> errors = item.getErrors();
                    for(String err : errors){
                        errmsg.append(err);
                    }
                    json.put("message",errmsg.toString());
                }
                mdMappingsList.add(json);
            }

        }
    }


    private void groupTerminalList(List<JSONObject> mdMappingsList,OpenApiResult result,Map<String,String>entityCodeMap,Map<String,String>mainIdMap,String operateType){
        String entity = "bd_customer";
        String tempId = "100000";
        String appId = "basedata";
        Long useOrgId = Long.parseLong(tempId);
        AssignService assignService = new AssignService(entity, false);
        if("save".equals(operateType)){
            ApiSaveResult data = (ApiSaveResult)result.getData();
            List<ApiSaveItemData> saveItemList = data.getResult();
            for(ApiSaveItemData item : saveItemList){
                JSONObject json = new JSONObject();
                String mdmCode = item.getKeys().get("number");
                json.put("mdmCode",mainIdMap.get(mdmCode));
                json.put("entityCode",entityCodeMap.get(mdmCode));
                json.put("busiDataId",item.getId());
                json.put("success",item.isBillStatus());
                if(item.isBillStatus()){
                        json.put("message","该条主数据消费成功！");
                }else{
                    StringBuffer errmsg = new StringBuffer();
                    for(ApiSaveRowErrorData errer:item.getErrors()){
                        //明细错误拼接
                        Set<String> rowMsg = errer.getRowMsg();
                        for(String err:rowMsg){
                            errmsg.append(err);
                        }
                    }
                    json.put("message",errmsg.toString());

                }
                mdMappingsList.add(json);
            }
        }else{
            BaseFilterResult data = (BaseFilterResult)result.getData();
            List<BaseFilterItemData> itemList = data.getResult();
            for(BaseFilterItemData item : itemList){
                JSONObject json = new JSONObject();
                String mdmCode = item.getNumber();
                json.put("mdmCode",mainIdMap.get(mdmCode));
                json.put("entityCode",entityCodeMap.get(mdmCode));
                json.put("busiDataId",item.getId());
                json.put("success",item.isBillStatus());
                if(item.isBillStatus()){
                    json.put("message","该条主数据消费成功！");
                }else{
                    StringBuffer errmsg = new StringBuffer();
                    List<String> errors = item.getErrors();
                    for(String err : errors){
                        errmsg.append(err);
                    }
                    json.put("message",errmsg.toString());
                }
                mdMappingsList.add(json);
            }

        }
    }

//    @ApiPostMapping(value="costCenterURLApiHandler")
//    public JSONObject costCenterApiHandler(@Valid @ApiParam("入口参数") CostCenterApiReqModel reqModel) {
//        String reqData=reqModel.getData();
//        JSONArray reqList = JSONObject.parseArray(reqData);
//
//        //获取系统现有客户数据,并且将系统中的启用禁用状态、主数据ID分别放入两个map,分组判断时从map中获取数据
//        Map<String,String> sysEnableStatusMap = new HashMap<String,String>();
//        Map<String,String> sysMainIdMap = new HashMap<String,String>();
//        Map<String,String> entityCodeMap = new HashMap<String,String>();
//        Map<String,String> mainID_NumberMap = new HashMap<String,String>();
//        Map<String,String> number_MainIdMap = new HashMap<String,String>();
//        DynamicObjectCollection systemCustomList = QueryServiceHelper.query("yrpg_bd_customer_ext", "number,yrpg_main_id,enable", new QFilter[]{});
//        for(DynamicObject sysCustomData : systemCustomList){
//            sysEnableStatusMap.put(sysCustomData.getString("yrpg_main_id"),sysCustomData.getString("enable"));
//            sysMainIdMap.put(sysCustomData.getString("yrpg_main_id"),sysCustomData.getString("number"));
//            number_MainIdMap.put(sysCustomData.getString("number"),sysCustomData.getString("yrpg_main_id"));
//        }
//
//
//        JSONArray saveList = new JSONArray();       //只需要进行save操作的数据
//        JSONArray enableList = new JSONArray();     //启用数据,先进行启用操作，再save
//        JSONArray disableList = new JSONArray();    //禁用数据，直接禁用操作，不需要save
//        JSONArray doneList = new JSONArray();       //不需要进行任何操作的数据，返回时直接认为操作成功
//        List<String> disableIds = new ArrayList<String>();
//        List<String> enableIds = new ArrayList<String>();
//
//        //数据分组，根据系统中是否已存在、启用、禁用状态进行分组
//        for(int i=0; i<reqList.size(); i++){
//            JSONObject reqJson = reqList.getJSONObject(i);
//            entityCodeMap.put(reqJson.getString("yrpg_main_id"),reqJson.getString("entityCode"));
//            mainID_NumberMap.put(reqJson.getString("yrpg_main_id"),reqJson.getString("number"));
//            String enableStatus = reqJson.getString("enable");
//            String yrpg_main_id = reqJson.getString("yrpg_main_id");
//            //-------------------系统中赞不存在的数据------------------------
//            if(sysMainIdMap.get(yrpg_main_id) == null){
//                if("0".equals(enableStatus)){
//                    //不存在，且需要禁用的，不做处理，放入doneList
//                    doneList.add(reqJson);
//                }else{
//                    //不存在，且需要启用的，直接save，默认就是开启状态，放入saveList
//                    saveList.add(reqJson);
//                }
//            }else{
//                //-------------------系统中已存在的数据---------------------
//                if("1".equals(enableStatus) && "1".equals(sysEnableStatusMap.get(yrpg_main_id))){
//                    //启用，系统中已经是启用状态的,只需要save,放入saveList
//                    saveList.add(reqJson);
//                } else if ("1".equals(enableStatus) && "0".equals(sysEnableStatusMap.get(yrpg_main_id))) {
//                    //启用，系统中是禁用状态的,放入enableList
//                    enableList.add(reqJson);
//                    enableIds.add(yrpg_main_id);
//                } else if ("0".equals(enableStatus) && "0".equals(sysEnableStatusMap.get(yrpg_main_id))) {
//                    //禁用，系统中已经是禁用状态的，不需要任何操作，放入doneList
//                    doneList.add(reqJson);
//                }else if("0".equals(enableStatus) && "1".equals(sysEnableStatusMap.get(yrpg_main_id))){
//                    //禁用，系统中是启用状态的额，放入disableList
//                    disableList.add(reqJson);
//                    disableIds.add(yrpg_main_id);
//                }else{
//                    //不满足条件的统一不做任何处理
//                    doneList.add(reqJson);
//                }
//            }
//            //-------------------分组判断结束------------------------------
//        }
//
////        List<JSONObject> successList = new ArrayList<JSONObject>();
////        List<JSONObject> failList = new ArrayList<JSONObject>();
//        List<JSONObject> mdMappingsList = new ArrayList<JSONObject>();
//
//
//        //save数据处理
//        if(saveList.size() > 0){
//            JSONObject saveJson = new JSONObject();
//            saveJson.put("data",saveList);
//            OpenApiResult saveReult = OpenApiSdkUtil.invoke("/v2/yrpg/basedata/bd_customer/saveCostomer", saveJson, new HashMap<>());
//            groupList(mdMappingsList,saveReult,mainID_NumberMap,number_MainIdMap,entityCodeMap,"save");
//        }
//
//        //禁用数据处理
//        if(disableList.size() > 0){
//            JSONObject disableJson = new JSONObject();
//            JSONObject ids = new JSONObject();
//            ids.put("yrpg_main_id",disableIds);
//            disableJson.put("data",ids);
//            OpenApiResult disableReult = OpenApiSdkUtil.invoke("/v2/yrpg/basedata/bd_customer/bd_customer_disable", disableJson, new HashMap<>());
//            groupList(mdMappingsList,disableReult,mainID_NumberMap,number_MainIdMap,entityCodeMap,"disable");
//        }
//        //启用数据处理
//        if(enableList.size() > 0) {
//            JSONObject enableJson = new JSONObject();
//            JSONObject ids = new JSONObject();
//            ids.put("yrpg_main_id",enableIds);
//            enableJson.put("data",ids);
//            //调用启用接口
//            OpenApiSdkUtil.invoke("/v2/yrpg/basedata/bd_customer/bd_customer_enable", enableJson, new HashMap<>());
//            //调用save接口
//            enableJson.put("data",enableList);
//            OpenApiResult saveReult = OpenApiSdkUtil.invoke("/v2/yrpg/basedata/bd_customer/saveCostomer", enableJson, new HashMap<>());
//            groupList(mdMappingsList, saveReult, mainID_NumberMap,number_MainIdMap, entityCodeMap, "save");
//        }
//
//        //不需要操作的数据直接封装成功返回
//        if(doneList.size()>0){
//            for(int i=0;i<doneList.size();i++){
//                JSONObject reqJson = doneList.getJSONObject(i);
//                JSONObject json = new JSONObject();
//                json.put("mdmCode",reqJson.getString("number"));
//                json.put("entityCode",reqJson.getString("entityCode"));
//                json.put("busiDataId","");
//                json.put("message","该条主数据消费成功！");
//                json.put("success",true);
//                mdMappingsList.add(json);
//            }
//        }
//        JSONObject returnResult = new JSONObject();
//        returnResult.put("success",true);
//        returnResult.put("message", "消费系统消费这批数据成功！");
//        returnResult.put("mdMappings",mdMappingsList);
//        return returnResult;
//    }
//
//    private void groupList(List<JSONObject> mdMappingsList,OpenApiResult result,Map<String,String>mainID_NumberMap,Map<String,String> number_MainIdMap,Map<String,String>entityCodeMap,String operateType){
//        JSONObject returnJson = JSONObject.parseObject(result.getData().toString());
//        JSONArray resultList = returnJson.getJSONArray("result");
//        for(int i=0;i<resultList.size();i++){
//            JSONObject returnScopeJson = resultList.getJSONObject(i);
//            JSONObject json = new JSONObject();
//            //根据mainId获取用友传参的number,
//            //用友number
//            String mainId = "";
//            String yongyouNumber = "";
//            //save和disable获取mainId方式不同
//            if("save".equals(operateType)){
//                //save时，接口会直接返回yrpg_main_id;
//                mainId = returnScopeJson.getJSONObject("keys").getString("yrpg_main_id");
//                yongyouNumber = mainID_NumberMap.get(mainId);
//            }else{
//                //disable时，接口只返回金蝶中的number,此时金蝶和用友可能number不一致，需要先通过金蝶的number获取yrpg_main_id，在通过yrpg_main_id获取用友的number返回
//                String kingDeeNumber = returnScopeJson.getString("number");
//                mainId = number_MainIdMap.get(kingDeeNumber);
//                yongyouNumber = mainID_NumberMap.get(mainId);
//            }
//            json.put("mdmCode",yongyouNumber);
//            json.put("entityCode",entityCodeMap.get(mainId));
//            json.put("busiDataId",returnScopeJson.getString("id"));
//            boolean billStatus = returnScopeJson.getBoolean("billStatus");
//            json.put("success",billStatus);
//            if(billStatus){
//                json.put("message","该条主数据消费成功");
//                //successList.add(json);
//            }else{
//                if("save".equals(operateType)){
//                    StringBuffer errorMsg = new StringBuffer();
//                    JSONArray errors = returnScopeJson.getJSONArray("errors");
//                    for(int j=0;j<errors.size();j++){
//                        JSONObject err = errors.getJSONObject(j);
//                        JSONArray rowMsgs = err.getJSONArray("rowMsg");
//                        for(int k=0;k<rowMsgs.size();k++){
//                            errorMsg.append(rowMsgs.getString(k));
//                        }
//                    }
//                    json.put("message",errorMsg.toString());
//                }else{
//                    StringBuffer errorMsg = new StringBuffer();
//                    JSONArray errors = returnScopeJson.getJSONArray("errors");
//                    for(int j =0;j<errors.size();j++){
//                        errorMsg.append(errors.getString(j));
//                    }
//                    json.put("message",errorMsg.toString());
//                }
//                //failList.add(json);
//            }
//            mdMappingsList.add(json);
//        }
//    }
}
